@@ -29,10 +29,8 @@
 #include <stdio.h>
 
 #ifdef NEED_GNOMESUPPORT_H
-#include "pixmaps/stock-zoom-in-menu.xpm"
-#include "pixmaps/stock-zoom-out-menu.xpm"
-
 #include <gnome.h>
+#include "setup.h"
 #else /* NEED_GNOMESUPPORT_H */
 #include <gtk/gtk.h>
 #endif /* NEED_GNOMESUPPORT_H */
@@ -78,24 +76,24 @@ gnome_menu_bar_new (ViewerData *viewer_data)
     {
       GNOME_APP_UI_ITEM, N_("Zoom in"),
       NULL, (gpointer) zoomin_cb, viewer_data, NULL,
-      GNOME_APP_PIXMAP_DATA, stock_zoom_in_menu_xpm,
+      GNOME_APP_PIXMAP_STOCK, STOCK_ZOOM_IN_MENU,
       0, (GdkModifierType) 0, NULL
     },
     {
       GNOME_APP_UI_ITEM, N_("Zoom out"),
       NULL, (gpointer) zoomout_cb, viewer_data, NULL,
-      GNOME_APP_PIXMAP_DATA, stock_zoom_out_menu_xpm,
+      GNOME_APP_PIXMAP_STOCK, STOCK_ZOOM_OUT_MENU,
       0, (GdkModifierType) 0, NULL
     },
     GNOMEUIINFO_SEPARATOR,
     {
-      GNOME_APP_UI_ITEM, N_("Rotate 90" DEGREES " clockwise"),
+      GNOME_APP_UI_ITEM, N_("Rotate 90 degrees clockwise"),
       NULL, (gpointer) right90_cb, viewer_data, NULL,
       GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REDO,
       0, (GdkModifierType) 0, NULL
     },
     {
-      GNOME_APP_UI_ITEM, N_("Rotate 90" DEGREES " counter-clockwise"),
+      GNOME_APP_UI_ITEM, N_("Rotate 90 degrees counter-clockwise"),
       NULL, (gpointer) left90_cb, viewer_data, NULL,
       GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_UNDO,
       0, (GdkModifierType) 0, NULL
@@ -172,9 +170,9 @@ view_menu_new (ViewerData *viewer_data)
   menu_item_new (view_menu, _("Zoom in"), zoomin_cb, viewer_data);
   menu_item_new (view_menu, _("Zoom out"), zoomout_cb, viewer_data);
   menu_separator_new (view_menu);
-  menu_item_new (view_menu, _("Rotate 90" DEGREES " clockwise"),
+  menu_item_new (view_menu, _("Rotate 90 degrees clockwise"),
 		 right90_cb, viewer_data);
-  menu_item_new (view_menu, _("Rotate 90" DEGREES " counter-clockwise"),
+  menu_item_new (view_menu, _("Rotate 90 degrees counter-clockwise"),
 		 left90_cb, viewer_data);
   menu_item_new (view_menu, _("Reverse image"),
 		 reverse_cb, viewer_data);
